aboutsummaryrefslogtreecommitdiffstats
path: root/print
diff options
context:
space:
mode:
authordanilo <danilo@FreeBSD.org>2014-09-07 21:34:45 +0800
committerdanilo <danilo@FreeBSD.org>2014-09-07 21:34:45 +0800
commit6d4ebe7ea496e6b845d4cd7512d7abb25cb99dda (patch)
tree367af321821ae9ae22fc91fa725238f563165974 /print
parentda3c5dfc1ae8e722a082871a428f72351459f248 (diff)
downloadfreebsd-ports-gnome-6d4ebe7ea496e6b845d4cd7512d7abb25cb99dda.tar.gz
freebsd-ports-gnome-6d4ebe7ea496e6b845d4cd7512d7abb25cb99dda.tar.zst
freebsd-ports-gnome-6d4ebe7ea496e6b845d4cd7512d7abb25cb99dda.zip
- Update from 1.2.2 to 2.0
- Update the pkg-descr
Diffstat (limited to 'print')
-rw-r--r--print/cups-bjnp/Makefile6
-rw-r--r--print/cups-bjnp/distinfo4
-rw-r--r--print/cups-bjnp/files/patch-bjnp-debug.c104
-rw-r--r--print/cups-bjnp/pkg-descr2
4 files changed, 58 insertions, 58 deletions
diff --git a/print/cups-bjnp/Makefile b/print/cups-bjnp/Makefile
index 9cfdd614c2fc..88a9ac494292 100644
--- a/print/cups-bjnp/Makefile
+++ b/print/cups-bjnp/Makefile
@@ -1,7 +1,7 @@
# $FreeBSD$
PORTNAME= cups-bjnp
-PORTVERSION= 1.2.2
+PORTVERSION= 2.0
CATEGORIES= print
MASTER_SITES= SF
@@ -11,9 +11,9 @@ COMMENT= CUPS backend for Canon USB over IP protocol
LIB_DEPENDS= libcups.so:${PORTSDIR}/print/cups-client
BUILD_DEPENDS= ${LOCALBASE}/libexec/cups/backend:${PORTSDIR}/print/cups-base
-PORTSCOUT= ignore:1.9.*
-
GNU_CONFIGURE= yes
+# Just to avoid a tautological pointer compare in bjnp-commands.c:187
+CONFIGURE_ARGS+= --disable-Werror
CPPFLAGS+= -I${LOCALBASE}/include
LDFLAGS+= -L${LOCALBASE}/lib
diff --git a/print/cups-bjnp/distinfo b/print/cups-bjnp/distinfo
index a612590eaa7d..42b4d6698906 100644
--- a/print/cups-bjnp/distinfo
+++ b/print/cups-bjnp/distinfo
@@ -1,2 +1,2 @@
-SHA256 (cups-bjnp-1.2.2.tar.gz) = 35db05f0a93d969d58f6969e15be9039eadab9c663a895daaf3a22a743dd6069
-SIZE (cups-bjnp-1.2.2.tar.gz) = 141557
+SHA256 (cups-bjnp-2.0.tar.gz) = 2acb716680d66f1378cf8dcd45fedf7f72ccc9b66fa80214d6dcb042b5e3c9ab
+SIZE (cups-bjnp-2.0.tar.gz) = 140617
diff --git a/print/cups-bjnp/pkg-descr b/print/cups-bjnp/pkg-descr
index 4c75749a0143..3abada6559b3 100644
--- a/print/cups-bjnp/pkg-descr
+++ b/print/cups-bjnp/pkg-descr
@@ -1,6 +1,6 @@
CUPS backend for the canon proprietary USB over IP network printing
protocol, BJNP. This backend is based on reverse engineering using
-TCP/IP. It can be used with CUPS 1.2 - 1.6 (verified). This backend allows Cups
+TCP/IP. It can be used with CUPS 1.2 - 1.7 (verified). This backend allows Cups
to connect over the network to a Canon printers
WWW: http://cups-bjnp.sourceforge.net/
diff --git a/print/cups-bjnp/files/patch-bjnp-debug.c b/print/cups-bjnp/files/patch-bjnp-debug.c
index 19c8dbd627c1..7a7b3bfb722c 100644
--- a/print/cups-bjnp/files/patch-bjnp-debug.c
+++ b/print/cups-bjnp/files/patch-bjnp-debug.c
@@ -1,6 +1,6 @@
---- bjnp-debug.c.orig 2013-01-21 10:43:27.000000000 -0800
-+++ bjnp-debug.c 2013-08-14 02:29:30.000000000 -0700
-@@ -19,7 +19,7 @@
+--- bjnp-debug.c.orig 2014-09-06 12:38:15 UTC
++++ bjnp-debug.c
+@@ -20,7 +20,7 @@
#include <stdio.h>
#include <stdarg.h>
@@ -9,64 +9,64 @@
#include <errno.h>
#include "bjnp.h"
-@@ -59,7 +59,7 @@
- static int to_cups = 0;
+@@ -58,7 +58,7 @@
+ static bjnp_loglevel_t debug_level = LOG_ERROR;
static FILE *debug_file = NULL;
static time_t start_sec = 0;
-static int start_msec;
+static suseconds_t start_usec;
- /*
+ /*
* local functions
-@@ -186,9 +186,9 @@
+@@ -192,9 +192,9 @@
{
- va_list ap;
- char printbuf[256];
-- struct timeb timebuf;
-+ struct timeval timebuf;
- int sec;
-- int msec;
-+ suseconds_t usec;
+ va_list ap;
+ char printbuf[1024];
+- struct timeb timebuf;
++ struct timeval timebuf;
+ int sec;
+- int msec;
++ suseconds_t usec;
- /* print received data into a string */
- va_start (ap, fmt);
-@@ -204,15 +204,15 @@
+ if (level <= debug_level) {
+ /* print received data into a string */
+@@ -211,16 +211,16 @@
+ /* all log messages may go to the own logfile */
- if ((level <= debug_level) && debug_file)
- {
-- ftime (&timebuf);
-- if ((msec = timebuf.millitm - start_msec) < 0)
-+ gettimeofday (&timebuf, NULL);
-+ if ((usec = timebuf.tv_usec - start_usec) < 0)
- {
-- msec += 1000;
-- timebuf.time -= 1;
-+ usec += 1000000;
-+ timebuf.tv_sec -= 1;
- }
-- sec = timebuf.time - start_sec;
-+ sec = timebuf.tv_sec - start_sec;
+ if (debug_file != NULL) {
+- ftime(&timebuf);
++ gettimeofday (&timebuf, NULL);
-- fprintf (debug_file, "%8s: %03d.%03d %s", level2str (level), sec, msec,
-+ fprintf (debug_file, "%8s: %03d.%06ld %s", level2str (level), sec, usec,
- printbuf);
- }
- }
-@@ -224,13 +224,13 @@
- * set debug level to level (string)
- */
+- if ((msec = timebuf.millitm - start_msec) < 0) {
+- msec += 1000;
+- timebuf.time -= 1;
++ if ((usec = timebuf.tv_usec - start_usec) < 0) {
++ usec += 1000000;
++ timebuf.tv_sec -= 1;
+ }
-- struct timeb timebuf;
-+ struct timeval timebuf;
- char loglevel[16];
- char *separator;
-
-- ftime (&timebuf);
-- start_sec = timebuf.time;
-- start_msec = timebuf.millitm;
-+ gettimeofday (&timebuf, NULL);
-+ start_sec = timebuf.tv_sec;
-+ start_usec = timebuf.tv_usec;
+- sec = timebuf.time - start_sec;
++ sec = timebuf.tv_sec - start_sec;
- /*
- * Split string into loglevel and optional cupslog string
+- fprintf(debug_file, "%8s: %03d.%03d %s", level2str(level), sec, msec,
++ fprintf(debug_file, "%8s: %03d.%06ld %s", level2str(level), sec, usec,
+ printbuf);
+ fflush(debug_file);
+ }
+@@ -234,12 +234,12 @@
+ * set debug level to level (string)
+ */
+
+- struct timeb timebuf;
++ struct timeval timebuf;
+ char loglevel[16];
+
+- ftime(&timebuf);
+- start_sec = timebuf.time;
+- start_msec = timebuf.millitm;
++ gettimeofday (&timebuf, NULL);
++ start_sec = timebuf.tv_sec;
++ start_usec = timebuf.tv_usec;
+
+ /*
+ * Set log level